#######
BCI Lib
#######

|test| |codecov| |docs| |pypi| 

.. |test| image:: https://github.com/intsystems/bci-ml/workflows/test/badge.svg
    :target: https://github.com/intsystems/bci-ml/tree/master
    :alt: Test status

.. |codecov| image:: https://codecov.io/gh/intsystems/bci-ml/branch/master/graph/badge.svg?token=MK7O5AH3MG 
    :target: https://codecov.io/gh/intsystems/bci-ml
    :alt: Test coverage

.. |docs| image:: https://github.com/intsystems/bci-ml/workflows/docs/badge.svg
    :target: https://github.com/intsystems/bci-ml/
    :alt: Build status

.. |pypi| image:: https://img.shields.io/pypi/v/bci-ml
    :target: https://pypi.org/project/bci-ml/
    :alt: PyPI

Basic information
=================

Implementation code for BCI models. The `source code <https://github.com/intsystems/bci-ml/tree/master/src>`_ presented on the github.

All methods were implemented based on ``pytorch`` for simple parallelization by using ``cuda``.

All information about this project can be found in the `documentation <https://intsystems.github.io/bci-ml/>`_.

Requirements and Installation
=============================
A simple instruction of installation using pip is provided near the `source code <https://github.com/intsystems/bci-ml/tree/master/src>`_.

More information about installation can be found in documentation `installation <https://intsystems.github.io/bci-ml/installation.html>`_ page.

Example of use
==============
A simple examples of module usage can be found in documentation `example <https://intsystems.github.io/bci-ml/example.html>`_ page.


